@@ -1,10 +1,10 @@
-package Yahoo::Marketing::keywordEditorialReasons;
+package Yahoo::Marketing::KeywordEditorialReasons;
 # Copyright (c) 2006 Yahoo! Inc.  All rights reserved.
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997)
 
 use strict; use warnings;
 
-use base qw/Yahoo::Marketing::ComplexType/;
+use base qw/Yahoo::Marketing::EditorialReasons/;
 
 =head1 NAME
 
@@ -28,6 +28,7 @@ sub _read_only_attributes {
                   urlEditorialReasons
                   urlStringEditorialReasons
                / );
+}
 
 __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
                            __PACKAGE__->_read_only_attributes
